@@ -27,7 +27,7 @@ class OpenIDConnect(flask_oidc.OpenIDConnect):
             def decorated(*args, **kwargs):
                 # get token & check if it's valid
                 token = self.get_token_from_request()
-                validity = self.validate_token(token)
+                validity = self.validate_token(token, scopes_required, keycloak_role, client, checks)
                 if validity is True or not require_token:
                     return view_func(*args, **kwargs)
 
